@@ -3,7 +3,7 @@ package Pod::Weaver::Plugin::Bencher::Scenario;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-07-31'; # DATE
 our $DIST = 'Pod-Weaver-Plugin-Bencher-Scenario'; # DIST
-our $VERSION = '0.251'; # VERSION
+our $VERSION = '0.252'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -684,7 +684,7 @@ Pod::Weaver::Plugin::Bencher::Scenario - Plugin to use when building Bencher::Sc
 
 =head1 VERSION
 
-This document describes version 0.251 of Pod::Weaver::Plugin::Bencher::Scenario (from Perl distribution Pod-Weaver-Plugin-Bencher-Scenario), released on 2021-07-31.
+This document describes version 0.252 of Pod::Weaver::Plugin::Bencher::Scenario (from Perl distribution Pod-Weaver-Plugin-Bencher-Scenario), released on 2021-07-31.
 
 =head1 SYNOPSIS
 
@@ -770,10 +770,10 @@ already excluded.
 
 =head2 sample_bench+ => hash
 
-Add a sample benchmark. Value is a hash which can contain these keys: C<title>
-(specify title for the benchmark), C<args> (hash arguments for bencher()) or
-C<file> (instead of running bencher(), use the result from JSON file). Can be
-specified multiple times.
+Add a sample benchmark. Value is a hash which can contain these keys:
+C<cmdline_comment> (specify commenttitle for the benchmark command), C<args>
+(hash arguments for bencher()) or C<file> (instead of running bencher(), use the
+result from JSON file). Can be specified multiple times.
 
 =head2 bench => bool (default: 1)
 
